==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Señes del to sitiu', # MODIF
	'form_pet_aucune_signature' => 'Denguna robla concasa con esi códigu...', # MODIF
	'form_pet_confirmation' => 'Confirma equí la to firma:',
	'form_pet_deja_signe' => 'Ya roblaste esti testu.',
	'form_pet_envoi_mail_confirmation' => 'Acaba de mandase un corréu electrónicu de confirmación a @email@. Vas tener que visitar la direición Web que se menta nesi corréu pa validar la to firma.', # MODIF
	'form_pet_mail_confirmation' => 'Bones,

Vienes de pidir la firma de la solicitú:
@titre@.

Pa ello diste la siguiente información:
    Nome: @nom_email@
    Sitiu Web: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Pa validar la to firma, val con conectate a la
direición d’embaxo (en casu contrariu, va refugase
la to solicitú):

    @url@


Gracies por participar
',
	'form_pet_nom_site2' => 'Nome del to sitiu Web', # MODIF
	'form_pet_probleme_liens' => 'Ties que iguar el to mensaxe quitando-y los enllaces d’hipertestu.',
	'form_pet_probleme_technique' => 'Hai un problema téunicu, les firmes tan temporalmente suspendíes.',
	'form_pet_signature_validee' => 'La to firma ta validada. ¡Gracies!',
	'form_pet_site_deja_enregistre' => 'Esti sitiu ya ta rexistráu',
	'form_pet_url_invalide' => 'L’URL que indicaste nun ye válida.',
	'form_pet_votre_email' => 'Les tos señes de corréu electrónicu',
	'form_pet_votre_nom' => 'El to nome o nomatu', # MODIF
	'form_pet_votre_site' => 'Si tienes un sitiu Web, puedes conseñalu darréu',

	// I
	'info_adresse_email' => 'SEÑES D’EMAIL:',
	'info_signature_supprimee' => 'Robla desaniciada',
	'info_signature_supprimee_erreur' => 'Error: esi códigu de desaniciu nun concasa con denguna robla', # MODIF
	'info_site_web' => 'SITIU WEB:',

	// L
	'lien_reponse_article' => 'Respuesta a l’artículu'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la solicitú',
	'bouton_radio_pas_petition' => 'Ensin solicitú',
	'bouton_radio_petition_activee' => 'Solicitú activada',
	'bouton_radio_supprimer_petition' => 'Desaniciar la solicitú',

	// F
	'form_pet_adresse_site' => 'Señes del to sitiu', # MODIF
	'form_pet_aucune_signature' => 'Denguna robla concasa con esi códigu...', # MODIF
	'form_pet_confirmation' => 'Confirma equí la to firma:',
	'form_pet_deja_signe' => 'Ya roblaste esti testu.',
	'form_pet_envoi_mail_confirmation' => 'Acaba de mandase un corréu electrónicu de confirmación a @email@. Vas tener que visitar la direición Web que se menta nesi corréu pa validar la to firma.', # MODIF
	'form_pet_mail_confirmation' => 'Bones,

Vienes de pidir la firma de la solicitú:
@titre@.

Pa ello diste la siguiente información:
    Nome: @nom_email@
    Sitiu Web: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Pa validar la to firma, val con conectate a la
direición d’embaxo (en casu contrariu, va refugase
la to solicitú):

    @url@


Gracies por participar
',
	'form_pet_nom_site2' => 'Nome del to sitiu Web', # MODIF
	'form_pet_probleme_liens' => 'Ties que iguar el to mensaxe quitando-y los enllaces d’hipertestu.',
	'form_pet_probleme_technique' => 'Hai un problema téunicu, les firmes tan temporalmente suspendíes.',
	'form_pet_signature_validee' => 'La to firma ta validada. ¡Gracies!',
	'form_pet_site_deja_enregistre' => 'Esti sitiu ya ta rexistráu',
	'form_pet_url_invalide' => 'L’URL que indicaste nun ye válida.',
	'form_pet_votre_email' => 'Les tos señes de corréu electrónicu',
	'form_pet_votre_nom' => 'El to nome o nomatu', # MODIF
	'form_pet_votre_site' => 'Si tienes un sitiu Web, puedes conseñalu darréu',

	// I
	'info_adresse_email' => 'SEÑES D’EMAIL:',
	'info_signature_supprimee' => 'Robla desaniciada',
	'info_signature_supprimee_erreur' => 'Error: esi códigu de desaniciu nun concasa con denguna robla', # MODIF
	'info_site_web' => 'SITIU WEB:',

	// L
	'lien_reponse_article' => 'Respuesta a l’artículu'
);

?>
